@@ -27,7 +27,7 @@
 # Author   : Kenneth J. Pronovici <pronovic@ieee.org>
 # Language : Python (>= 2.3)
 # Project  : Cedar Backup, release 2
-# Revision : $Id: util.py 747 2007-03-25 19:42:43Z pronovic $
+# Revision : $Id: util.py 970 2010-05-22 16:37:38Z pronovic $
 # Purpose  : Implements action-related utilities
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
@@ -147,14 +147,15 @@ def createWriter(config):
    deviceScsiId = config.store.deviceScsiId
    driveSpeed = config.store.driveSpeed
    noEject = config.store.noEject
+   refreshMediaDelay = config.store.refreshMediaDelay
    deviceType = _getDeviceType(config)
    mediaType = _getMediaType(config)
    if deviceMounted(devicePath):
       raise IOError("Device [%s] is currently mounted." % (devicePath))
    if deviceType == "cdwriter":
-      return CdWriter(devicePath, deviceScsiId, driveSpeed, mediaType, noEject)
+      return CdWriter(devicePath, deviceScsiId, driveSpeed, mediaType, noEject, refreshMediaDelay)
    elif deviceType == "dvdwriter":
-      return DvdWriter(devicePath, deviceScsiId, driveSpeed, mediaType, noEject)
+      return DvdWriter(devicePath, deviceScsiId, driveSpeed, mediaType, noEject, refreshMediaDelay)
    else:
       raise ValueError("Device type [%s] is invalid." % deviceType)
 
