@@ -27,7 +27,7 @@
 # Author   : Kenneth J. Pronovici <pronovic@ieee.org>
 # Language : Python (>= 2.3)
 # Project  : Cedar Backup, release 2
-# Revision : $Id: filesystem.py 928 2008-11-15 18:12:43Z pronovic $
+# Revision : $Id: filesystem.py 950 2009-08-16 20:12:09Z pronovic $
 # Purpose  : Provides filesystem-related objects.
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
@@ -51,7 +51,6 @@ Provides filesystem-related objects.
 import sys
 import os
 import re
-import sha
 import math
 import logging
 import tarfile
@@ -115,7 +114,7 @@ class FilesystemList(list):
    because the operating system never reports a file as a soft link.
 
    @sort: __init__, addFile, addDir, addDirContents, removeFiles, removeDirs,
-          removeLinks, removeMatch, removeInvalid, normalize, validate, 
+          removeLinks, removeMatch, removeInvalid, normalize,
           excludeFiles, excludeDirs, excludeLinks, excludePaths, 
           excludePatterns, excludeBasenamePatterns, ignoreFile 
    """
@@ -899,7 +898,7 @@ class BackupFileList(FilesystemList):
       requires 111 seconds.  This implementation requires only 40-45 seconds,
       which is a pretty substantial speed-up.  
 
-      Practice shows that reading in around 4kB (4096 bytes) at a time yields
+      Experience shows that reading in around 4kB (4096 bytes) at a time yields
       the best performance.  Smaller reads are quite a bit slower, and larger
       reads don't make much of a difference.  The 4kB number makes me a little
       suspicious, and I think it might be related to the size of a filesystem
@@ -912,7 +911,12 @@ class BackupFileList(FilesystemList):
       @return: ASCII-safe SHA digest for the file.
       @raise OSError: If the file cannot be opened.
       """
-      s = sha.new()
+      try:
+         import hashlib
+         s = hashlib.sha1()
+      except:
+         import sha
+         s = sha.new()
       f = open(path, mode="rb")  # in case platform cares about binary reads
       readBytes = 4096  # see notes above
       while(readBytes > 0):
@@ -1101,7 +1105,10 @@ class BackupFileList(FilesystemList):
       else: raise ValueError("Mode [%s] is not valid." % mode)
       try:
          tar = tarfile.open(path, tarmode)
-         tar.posix = False    # make a GNU-compatible archive without file length limits
+         try:
+            tar.format = tarfile.GNU_FORMAT
+         except:
+            tar.posix = False
          for entry in self:
             try:
                if flat:
