@@ -30,7 +30,7 @@
 # Author   : Kenneth J. Pronovici <pronovic@ieee.org>
 # Language : Python (>= 2.3)
 # Project  : Cedar Backup, release 2
-# Revision : $Id: util.py 935 2009-03-29 18:56:50Z pronovic $
+# Revision : $Id: util.py 966 2010-02-23 22:29:55Z pronovic $
 # Purpose  : Provides general-purpose utilities.
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
@@ -1535,7 +1535,13 @@ def executeCommand(command, args, returnOutput=False, ignoreStderr=False, doNotL
    fields.extend(args)
    try:
       sanitizeEnvironment()   # make sure we have a consistent environment
-      pipe = Pipe(fields, ignoreStderr=ignoreStderr)
+      try:
+         pipe = Pipe(fields, ignoreStderr=ignoreStderr)
+      except OSError:
+         # On some platforms (i.e. Cygwin) this intermittently fails the first time we do it.
+         # So, we attempt it a second time and if that works, we just go on as usual.
+         # The problem appears to be that we sometimes get a bad stderr file descriptor.
+         pipe = Pipe(fields, ignoreStderr=ignoreStderr)
       while True:
          line = pipe.fromchild.readline()
          if not line: break
