@@ -27,7 +27,7 @@
 # Author   : Kenneth J. Pronovici <pronovic@ieee.org>
 # Language : Python (>= 2.3)
 # Project  : Cedar Backup, release 2
-# Revision : $Id: cdwriter.py 953 2010-01-10 22:28:08Z pronovic $
+# Revision : $Id: cdwriter.py 972 2010-05-22 16:51:20Z pronovic $
 # Purpose  : Provides functionality related to CD writer devices.
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
@@ -413,7 +413,8 @@ class CdWriter(object):
    ##############
 
    def __init__(self, device, scsiId=None, driveSpeed=None, 
-                mediaType=MEDIA_CDRW_74, noEject=False, unittest=False):
+                mediaType=MEDIA_CDRW_74, noEject=False, 
+                refreshMediaDelay=0, unittest=False):
       """
       Initializes a CD writer object.
 
@@ -454,6 +455,9 @@ class CdWriter(object):
       @param noEject: Overrides properties to indicate that the device does not support eject.
       @type noEject: Boolean true/false
 
+      @param refreshMediaDelay: Refresh media delay to use, if any
+      @type refreshMediaDelay: Number of seconds, an integer >= 0
+
       @param unittest: Turns off certain validations, for use in unit testing.
       @type unittest: Boolean true/false
 
@@ -468,6 +472,7 @@ class CdWriter(object):
       self._driveSpeed = validateDriveSpeed(driveSpeed)
       self._media = MediaDefinition(mediaType)
       self._noEject = noEject
+      self._refreshMediaDelay = refreshMediaDelay
       if not unittest:
          (self._deviceType,
           self._deviceVendor,
@@ -556,6 +561,12 @@ class CdWriter(object):
       """
       return self._deviceCanEject
 
+   def _getRefreshMediaDelay(self):
+      """
+      Property target used to get the configured refresh media delay, in seconds.
+      """
+      return self._refreshMediaDelay
+
    device = property(_getDevice, None, None, doc="Filesystem device name for this writer.")
    scsiId = property(_getScsiId, None, None, doc="SCSI id for the device, in the form C{[<method>:]scsibus,target,lun}.")
    hardwareId = property(_getHardwareId, None, None, doc="Hardware id for this writer, either SCSI id or device path.");
@@ -568,6 +579,7 @@ class CdWriter(object):
    deviceSupportsMulti = property(_getDeviceSupportsMulti, None, None, doc="Indicates whether device supports multisession discs.")
    deviceHasTray = property(_getDeviceHasTray, None, None, doc="Indicates whether the device has a media tray.")
    deviceCanEject = property(_getDeviceCanEject, None, None, doc="Indicates whether the device supports ejecting its media.")
+   refreshMediaDelay = property(_getRefreshMediaDelay, None, None, doc="Refresh media delay, in seconds.")
 
 
    #################################################
@@ -835,18 +847,24 @@ class CdWriter(object):
 
       Sometimes, a device gets confused about the state of its media.  Often,
       all it takes to solve the problem is to eject the media and then
-      immediately reload it.  
+      immediately reload it.  (There is also a configurable refresh media delay
+      which can be applied after the tray is closed, for situations where this
+      makes a difference.)
 
       This only works if the device has a tray and supports ejecting its media.
       We have no way to know if the tray is currently open or closed, so we
       just send the appropriate command and hope for the best.  If the device
       does not have a tray or does not support ejecting its media, then we do
-      nothing.
+      nothing.  The configured delay still applies, though.
 
       @raise IOError: If there is an error talking to the device.
       """
       self.openTray()
       self.closeTray()
+      if self.refreshMediaDelay is not None:
+         logger.debug("Per configuration, sleeping %d seconds to stabilize media state." % self.refreshMediaDelay)
+         time.sleep(self.refreshMediaDelay)
+         logger.debug("Sleep is complete; hopefully media state is stable now.")
 
    def writeImage(self, imagePath=None, newDisc=False, writeMulti=True):
       """
