@@ -28,7 +28,7 @@
 # Author   : Kenneth J. Pronovici <pronovic@ieee.org>
 # Language : Python (>= 2.3)
 # Project  : Cedar Backup, release 2
-# Revision : $Id: test.py 952 2010-01-10 20:11:53Z pronovic $
+# Revision : $Id: test.py 969 2010-05-22 16:25:56Z pronovic $
 # Purpose  : Run all of the unit tests for the project.
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
@@ -134,6 +134,10 @@ def main():
       print "tree, or properly set the PYTHONPATH enviroment variable."
       return 1
 
+   # Setup platform-specific command overrides
+   from CedarBackup2.testutil import setupOverrides
+   setupOverrides()
+
    # Import the unit test modules
    try:
       if os.path.exists(os.path.join(".", "test", "filesystemtests.py")):
